@@ -1,5 +1,5 @@
-# $Id: Unparsers.pm,v 1.4 2005/08/01 23:06:17 rvosa Exp $
-# Subversion: $Rev: 147 $
+# $Id: Unparsers.pm,v 1.6 2005/08/09 12:36:12 rvosa Exp $
+# Subversion: $Rev: 148 $
 
 package Bio::Phylo::Unparsers;
 use strict;
@@ -12,9 +12,9 @@ my @unparsers = qw(Newick Pagel Svg);
 # 'make dist' to build a *.tar.gz without the "_rev#" in the package name, while
 # it still shows up otherwise (e.g. during 'make test') as a developer release,
 # with the "_rev#".
-my $rev = '$Rev: 147 $';
+my $rev = '$Rev: 148 $';
 $rev =~ s/^[^\d]+(\d+)[^\d]+$/$1/;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 $VERSION .= '_' . $rev;
 my $VERBOSE = 1;
 use vars qw($VERSION);
@@ -101,9 +101,9 @@ sub unparse {
             $self->COMPLAIN("no valid parser found");
             return;
         }
-        my $unparser = new $lib;
+        my $unparser = $lib->new(%opts);
         if ( $unparser->can('to_string') ) {
-            return $unparser->to_string(%opts);
+            return $unparser->to_string;
         }
         else {
             $self->COMPLAIN("the unparser can't convert to strings");
@@ -117,6 +117,7 @@ sub unparse {
 =head1 AUTHOR
 
 Rutger Vos, C<< <rvosa@sfu.ca> >>
+L<http://www.sfu.ca/~rvosa/>
 
 =head1 BUGS
 
